@@ -93,6 +93,8 @@
 #' @param abseps specifies the absolute error tolerance (default: 0.001)
 #' @param seed a single value, interpreted as an integer;
 #' see \code{\link[base:Random]{set.seed()}} function. (default: NULL)
+#' @param nthread sthe number of threads used in parallel computing, or FALSE 
+#' that means single threading (default: 2)
 #' @return
 #' \item{statistic}{the value of the test statistic with a name describing it.}
 #' \item{p.value}{the p-value for the test.}
@@ -119,8 +121,6 @@
 #' @seealso
 #' \code{\link{mmcm.mvt}}
 #' @examples
-#' OpenMPController::omp_set_num_threads(2)
-#' 
 #' ## Example 1 ##
 #' #  true response pattern: dominant model c=(1, 1, -2)
 #' set.seed(136885)
@@ -142,14 +142,16 @@
 #' contrast <- rbind(
 #'   c(-1, 0, 1), c(-2, 1, 1), c(-1, -1, 2)
 #' )
-#' y <- mmcm.resamp(x, g, contrast, nsample = 20000, abseps = 0.01, seed = 5784324)
+#' y <- mmcm.resamp(x, g, contrast, nsample = 20000,
+#'                  abseps = 0.01, seed = 5784324)
 #' y
 #' 
 #' ## Example 2 ##
 #' #  for dataframe
-#' #  true response pattern: pos = 1 dominant  model c=( 1,  1, -2)
-#' #                               2 additive  model c=(-1,  0,  1)
-#' #                               3 recessive model c=( 2, -1, -1)
+#' #  true response pattern:
+#' #    pos = 1 dominant  model c=( 1,  1, -2)
+#' #          2 additive  model c=(-1,  0,  1)
+#' #          3 recessive model c=( 2, -1, -1)
 #' set.seed(3872435)
 #' x <- c(
 #'   rnorm(130, mean =  1 / 6, sd = 1),
@@ -163,7 +165,7 @@
 #'   rnorm( 10, mean = -1 / 6, sd = 1)
 #' )
 #' g   <- rep(rep(1:3, c(130, 90, 10)), 3)
-#' pos <- rep(c("rsXXXX", "rsYYYY", "rsZZZZ"), each=230)
+#' pos <- rep(c("rsXXXX", "rsYYYY", "rsZZZZ"), each = 230)
 #' xx  <- data.frame(pos = pos, x = x, g = g)
 #' 
 #' # coefficient matrix
@@ -172,26 +174,15 @@
 #'   c(-1, 0, 1), c(-2, 1, 1), c(-1, -1, 2)
 #' )
 #' 
-#' mmcmtapply <- function(r) {
-#'   mmcm.resamp(
-#'     xx$x[xx$pos==r[1]], xx$g[xx$pos==r[1]],
-#'     contrast, nsample = 10000, abseps = 0.01, seed = 5784324+as.numeric(r[1])
-#'   )
-#' }
-#' y <- tapply(xx$pos, xx$pos, mmcmtapply)
-#' yy <- data.frame(
-#'   Pos      = as.vector(names(y)),
-#'   Pval     = as.vector(sapply(y, "[[", 3)),
-#'   Pattern  = as.vector(sapply(y, "[[", 7)),
-#'   MC_Error = as.vector(sapply(y, "[[", 9))
-#' )
-#' yy
+#' y <- by(xx, xx$pos, function(x) mmcm.resamp(x$x, x$g,
+#'   contrast, abseps = 0.02, nsample = 10000))
+#' y <- do.call(rbind, y)[,c(3,7,9)]
+#' y
 #' @keywords htest
 #' @importFrom stats var
-#' @importFrom OpenMPController omp_set_num_threads
 #' @export
 mmcm.resamp <- function(x, g, contrast, alternative = c("two.sided", "less", "greater"),
-  nsample = 20000, abseps = 0.001, seed = NULL) {
+  nsample = 20000, abseps = 0.001, seed = NULL, nthread = 2) {
   
   ####################
   # executable check
@@ -215,6 +206,11 @@ mmcm.resamp <- function(x, g, contrast, alternative = c("two.sided", "less", "gr
   if (!is.matrix(contrast)) {
     stop(paste(DNAMEC, "must be a matrix"))
   }
+  if (!is.numeric(nthread)) {
+    nthread <- 1
+  } else if (nthread < 1) {
+    nthread <- 1
+  }
   
   x <- x[is.finite(x)]
   g <- g[is.finite(g)]
@@ -289,6 +285,7 @@ mmcm.resamp <- function(x, g, contrast, alternative = c("two.sided", "less", "gr
     as.integer(length(x)),
     as.double(abseps),
     as.integer(nalternative),
+    as.integer(nthread),
     pval=double(1),
     error=double(1)
   )
